@@ -1,4 +1,5 @@
-from typing import Any, List, Optional
+from pathlib import Path
+from typing import Any, List, Mapping, Optional
 
 from datamodel_code_generator.imports import Import
 from datamodel_code_generator.model.base import DataModel, DataModelField
@@ -17,6 +18,8 @@ class CustomRootType(DataModel):
         decorators: Optional[List[str]] = None,
         base_classes: Optional[List[str]] = None,
         custom_base_class: Optional[str] = None,
+        custom_template_dir: Optional[Path] = None,
+        extra_template_data: Optional[Mapping[str, Any]] = None,
         imports: Optional[List[Import]] = None,
         auto_import: bool = True,
         reference_classes: Optional[List[str]] = None,
@@ -27,6 +30,8 @@ class CustomRootType(DataModel):
             decorators=decorators,
             base_classes=base_classes,
             custom_base_class=custom_base_class,
+            custom_template_dir=custom_template_dir,
+            extra_template_data=extra_template_data,
             imports=imports,
             auto_import=auto_import,
             reference_classes=reference_classes,
